@@ -7,9 +7,11 @@
 
 extern crate rand;
 extern crate ndarray;
+extern crate ndarray_rand;
 extern crate float_cmp;
 extern crate num_complex;
 
 pub mod prelude;
 pub mod assert;
 pub mod random;
+pub mod random_init;
